echo preremove running

#
# Make sure directories are free of trailing slahses
#
# TODO:
#  HOST_OS may be able to be slurped from the pkgadd parameters
#  rather than re-established
#
if [ -f /etc/.relid ]
then
	HOST_OS=ncr
else
	HOST_OS=`uname -s`
fi

if [ "Windows" != "$HOST_OS" ]
then
	PKG_BASE=`head -n 1 /etc/.snapvault`
fi
STRIPPED_PKG_BASE="`echo $PKG_BASE | sed -e 's+\\$++' -e 's+/$++'`"
PKG_BASE="$STRIPPED_PKG_BASE"


if [ "Windows" = "$HOST_OS" -a -d "$PKG_BASE"/fltdrvr ]
	then
# Uninstall the filter driver
	"$PKG_BASE"/fltdrvr/filtercfg unload
	if [ 0 != $? ]
	then
		echo "Error unloading filter driver $?"
	fi
	cp "$PKG_BASE"/fltdrvr/changelog.inf  "${windir}/temp"
	if [ 0 != $? ]
	then
		echo "Error copying changelog inf file $?"
	fi
	"$PKG_BASE"/fltdrvr/filtercfg uninstall /path ${windir}/temp/changelog.inf
	if [ 0 != $? ]
	then
		echo "Error uninstalling filter driver $?"
	fi
	 rm "${windir}/temp/changelog.inf"
fi
#
# Establish the users temp directory, defaulting to /tmp
#
if [ "" = "$TMPDIR" ]
then
	echo "Using default /tmp as the temporary directory"
	TMPDIR=/tmp
	if [ "Windows" = "$HOST_OS" ]
	then
		TMPDIR="${TEMP}"
	fi
else
	echo "Using user specified temp directory $TMPDIR"
fi

#
# Include the file containing the common functions
#
if [ "Windows" != "$HOST_OS" ]
then
	if [ "SunOS" = "$HOST_OS" ]
	then
		. `pwd`/commonfuncs
	else
		. $PKG_BASE/uninstall/commonfuncs.sh
	fi

	if [ "Linux" = "$HOST_OS" ]
	then
		get_caffeine_info "$PKG_BASE"
	fi
fi

#
# TODO: Once all installers supply vars back, make them all use PKG_BASE
# relative paths
#
echo Removing OSSV services
if [ "Windows" = "$HOST_OS" ]
	then
	"$PKG_BASE"/bin/svpmgr shutdown
# Remove the db directories created for cluster support
	"$PKG_BASE"/cluster/mscs/svcluster uninstall
	"$PKG_BASE"/bin/svpmgr remove
else
	svpmgr shutdown
	svpmgr remove
#
# Sleeping for a second to allow the services to die down;
# otherwise the files svcmgr, svpmgr & libsv may not get removed
# when the files are deleted later on
#
	sleep 1

fi

#
# Copy shell files somewhere so that we'll be able to get at them for
# running the postremove script
#
if [ "Windows" = "$HOST_OS" ]
	then
	cp "$PKG_BASE"/installfiles/* "$PKG_BASE"/tmp
fi

#
# Generate a list of libraries for use by the postremove.sh script
#
ls "$PKG_BASE"/lib | grep libsv > "$TMPDIR"/liblist.txt

#
# Clean up Caffeine related stuff
#
if [ "Linux" = "$HOST_OS" -o "Windows" = "$HOST_OS" ]
then
# Stop and start service only if OSSV plugins are present
	if [ "Yes" = "$CAFFEINE_PRESENT" ]
	then
		CAFFEINE_OSSV="No"
		if [ "Linux" = "$HOST_OS" ]
		then
			if [ -f "$CAFFEINE_PATH"/libplugin_ossv.so ]
			then
				CAFFEINE_OSSV="Yes"
			fi
		else
			if [ -f "$CAFFEINE_PATH"/plugin_ossv.dll ]
			then
				CAFFEINE_OSSV="Yes"
			fi
		fi

		if  [ "Yes" = "$CAFFEINE_OSSV" ]
		then
			echo "Stopping $CAFFEINE_NAME"
			"$CAFFEINE_EXE" stop

			rm -f "$CAFFEINE_PATH"/*plugin_ossv*
			rm -f "$CAFFEINE_PATH"/*svmanage*

			echo "Starting $CAFFEINE_NAME"
			"$CAFFEINE_EXE" start
		else
			echo "OSSV Plugins are not installed with $CAFFEINE_NAME"
		fi
	else
		echo "$CAFFEINE_NAME is not found on the system"
	fi
fi

#
# Call the vmware uninstall script
#
if [ "Esx" = "$HOST_OS" ]
then
	"$PKG_BASE"/apps/vmware/ossvvmuninstall.sh
	if [ 0 != $? ]
	then
		echo "Error uninstalling vmware plugins"
	fi
fi

exit 0

